@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -33,8 +33,8 @@
  *      file system provider} to enumerate and read the class and resource
  *      files in a run-time image.
  *      The jrt file system can be created by calling
- *      {@link java.nio.file.FileSystems#newFileSystem
- *      FileSystems.newFileSystem(URI.create("jrt:/"))}.
+ *      {@link java.nio.file.FileSystems#getFileSystem
+ *      FileSystems.getFileSystem(URI.create("jrt:/"))}.
  *      </dd>
  * </dl>
  *
@@ -78,7 +78,13 @@ module java.base {
     exports java.io;
     exports java.lang;
     exports java.lang.annotation;
+    exports java.lang.classfile;
+    exports java.lang.classfile.attribute;
+    exports java.lang.classfile.components;
+    exports java.lang.classfile.constantpool;
+    exports java.lang.classfile.instruction;
     exports java.lang.constant;
+    exports java.lang.foreign;
     exports java.lang.invoke;
     exports java.lang.module;
     exports java.lang.ref;
@@ -137,16 +143,26 @@ module java.base {
         java.naming,
         java.rmi,
         jdk.charsets,
-        jdk.incubator.foreign,
+        jdk.crypto.cryptoki,
         jdk.jartool,
+        jdk.jfr,
         jdk.jlink,
-        jdk.net;
-    exports jdk.internal.access.foreign to jdk.incubator.foreign;
+        jdk.net,
+        jdk.sctp;
     exports jdk.internal.event to jdk.jfr;
-    exports jdk.internal.invoke to jdk.incubator.foreign;
+    exports jdk.internal.foreign to jdk.incubator.vector;
+    exports jdk.internal.io to
+        jdk.internal.le,
+        jdk.jshell;
     exports jdk.internal.javac to
         java.compiler,
+        java.desktop,
         jdk.compiler,
+        jdk.incubator.vector,
+        jdk.jartool,
+        jdk.jdeps,
+        jdk.jfr,
+        jdk.jlink,
         jdk.jshell;
     exports jdk.internal.jimage to jdk.jlink;
     exports jdk.internal.jimage.decompressor to jdk.jlink;
@@ -156,8 +172,7 @@ module java.base {
     exports jdk.internal.loader to
         java.instrument,
         java.logging,
-        java.naming,
-        jdk.incubator.foreign;
+        java.naming;
     exports jdk.internal.logger to java.logging;
     exports jdk.internal.misc to
         java.desktop,
@@ -171,7 +186,6 @@ module java.base {
         jdk.charsets,
         jdk.compiler,
         jdk.crypto.cryptoki,
-        jdk.incubator.foreign,
         jdk.incubator.vector,
         jdk.internal.vm.ci,
         jdk.jfr,
@@ -181,19 +195,14 @@ module java.base {
     exports jdk.internal.module to
         java.instrument,
         java.management.rmi,
-        jdk.incubator.foreign,
+        jdk.compiler,
         jdk.jartool,
         jdk.jfr,
         jdk.jlink,
         jdk.jpackage;
-    exports jdk.internal.org.objectweb.asm to
-        jdk.jartool,
-        jdk.jfr,
-        jdk.jlink;
+    exports jdk.internal.org.objectweb.asm to jdk.jfr;
     exports jdk.internal.org.objectweb.asm.commons to jdk.jfr;
-    exports jdk.internal.org.objectweb.asm.tree to
-        jdk.jfr,
-        jdk.jlink;
+    exports jdk.internal.org.objectweb.asm.tree to jdk.jfr;
     exports jdk.internal.org.objectweb.asm.util to jdk.jfr;
     exports jdk.internal.org.xml.sax to jdk.jfr;
     exports jdk.internal.org.xml.sax.helpers to jdk.jfr;
@@ -206,34 +215,42 @@ module java.base {
         jdk.management;
     exports jdk.internal.ref to
         java.desktop,
-        jdk.incubator.foreign;
+        java.net.http,
+        jdk.naming.dns;
     exports jdk.internal.reflect to
         java.logging,
         java.sql,
         java.sql.rowset,
         jdk.dynalink,
-        jdk.incubator.foreign,
         jdk.internal.vm.ci,
         jdk.unsupported;
-    exports jdk.internal.util to jdk.incubator.foreign;
-    exports jdk.internal.util.jar to jdk.jartool;
+    exports jdk.internal.util to
+        java.desktop,
+        java.prefs,
+        java.security.jgss,
+        java.smartcardio,
+        jdk.charsets,
+        jdk.internal.vm.ci,
+        jdk.jlink,
+        jdk.jpackage,
+        jdk.net;
     exports jdk.internal.util.random to jdk.random;
     exports jdk.internal.util.xml to jdk.jfr;
     exports jdk.internal.util.xml.impl to jdk.jfr;
     exports jdk.internal.vm to
+        java.management,
         jdk.internal.jvmstat,
+        jdk.internal.vm.ci,
+        jdk.management,
         jdk.management.agent;
     exports jdk.internal.vm.annotation to
         java.instrument,
-        jdk.incubator.foreign,
         jdk.incubator.vector,
         jdk.internal.vm.ci,
         jdk.jfr,
         jdk.unsupported;
     exports jdk.internal.vm.vector to jdk.incubator.vector;
-    exports sun.invoke.util to
-        jdk.compiler,
-        jdk.incubator.foreign;
+    exports sun.invoke.util to jdk.compiler;
     exports sun.net to
         java.net.http,
         jdk.naming.dns;
@@ -253,7 +270,6 @@ module java.base {
     exports sun.nio.ch to
         java.management,
         jdk.crypto.cryptoki,
-        jdk.incubator.foreign,
         jdk.net,
         jdk.sctp;
     exports sun.nio.cs to
@@ -271,24 +287,18 @@ module java.base {
         java.sql.rowset;
     exports sun.security.action to
         java.desktop,
-        java.security.jgss,
-        jdk.crypto.ec,
-        jdk.incubator.foreign;
+        java.security.jgss;
     exports sun.security.internal.interfaces to jdk.crypto.cryptoki;
     exports sun.security.internal.spec to jdk.crypto.cryptoki;
     exports sun.security.jca to
         java.smartcardio,
         jdk.crypto.cryptoki,
-        jdk.crypto.ec,
         jdk.naming.dns;
-    exports sun.security.pkcs to
-        jdk.crypto.ec,
-        jdk.jartool;
+    exports sun.security.pkcs to jdk.jartool;
     exports sun.security.provider to
         java.rmi,
         java.security.jgss,
         jdk.crypto.cryptoki,
-        jdk.crypto.ec,
         jdk.security.auth;
     exports sun.security.provider.certpath to
         java.naming,
@@ -305,16 +315,12 @@ module java.base {
         java.smartcardio,
         java.xml.crypto,
         jdk.crypto.cryptoki,
-        jdk.crypto.ec,
         jdk.jartool,
         jdk.security.auth,
         jdk.security.jgss;
-    exports sun.security.util.math to jdk.crypto.ec;
-    exports sun.security.util.math.intpoly to jdk.crypto.ec;
     exports sun.security.validator to jdk.jartool;
     exports sun.security.x509 to
         jdk.crypto.cryptoki,
-        jdk.crypto.ec,
         jdk.jartool;
     exports sun.util.cldr to jdk.jlink;
     exports sun.util.locale.provider to
@@ -356,6 +362,7 @@ module java.base {
     uses java.util.spi.TimeZoneNameProvider;
     uses java.util.spi.ToolProvider;
     uses javax.security.auth.spi.LoginModule;
+    uses jdk.internal.io.JdkConsoleProvider;
     uses jdk.internal.logger.DefaultLoggerFinder;
     uses sun.text.spi.JavaTimeDateTimePatternProvider;
     uses sun.util.locale.provider.LocaleDataMetaInfo;
