@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -71,161 +67,150 @@ public class CurrencyNames_sr_Latn extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
-            { "ALL", "ALL" },
             { "AUD", "AUD" },
             { "BAM", "KM" },
-            { "CHF", "CHF" },
-            { "CNH", "CNH" },
-            { "DKK", "DKK" },
-            { "HUF", "HUF" },
-            { "ISK", "ISK" },
             { "JPY", "\u00a5" },
             { "KRW", "KRW" },
-            { "NOK", "NOK" },
             { "NZD", "NZD" },
-            { "PES", "PES" },
-            { "SEK", "SEK" },
-            { "STN", "STN" },
-            { "SZL", "SZL" },
+            { "PHP", "PHP" },
             { "VND", "VND" },
-            { "ZAR", "ZAR" },
             { "adp", "Andorska pezeta" },
-            { "aed", "UAE dirham" },
+            { "aed", "dirham UAE" },
             { "afa", "Avganistanski avgani (1927\u20132002)" },
-            { "afn", "Avganistanski avgani" },
-            { "all", "Albanski lek" },
-            { "amd", "Jermenski dram" },
-            { "ang", "Holandskoantilski gulden" },
-            { "aoa", "Angolska kvanza" },
+            { "afn", "avganistanski avgani" },
+            { "all", "albanski lek" },
+            { "amd", "jermenski dram" },
+            { "ang", "holandskoantilski gulden" },
+            { "aoa", "angolska kvanza" },
             { "aok", "Angolijska kvanza (1977\u20131990)" },
             { "aon", "Angolijska nova kvanza (1990\u20132000)" },
             { "aor", "Angolijska kvanza rea\u0111ustado (1995\u20131999)" },
             { "ara", "Argentinski austral" },
             { "arp", "Argentinski pezo (1983\u20131985)" },
-            { "ars", "Argentinski pezos" },
+            { "ars", "argentinski pezos" },
             { "ats", "Austrijski \u0161iling" },
-            { "aud", "Australijski dolar" },
-            { "awg", "Arubanski florin" },
+            { "aud", "australijski dolar" },
+            { "awg", "arubanski florin" },
             { "azm", "Azerbejd\u017eanski manat (1993\u20132006)" },
-            { "azn", "Azerbejd\u017eanski manat" },
+            { "azn", "azerbejd\u017eanski manat" },
             { "bad", "Bosansko-Hercegova\u010dki dinar" },
-            { "bam", "Bosansko-hercegova\u010dka konvertibilna marka" },
-            { "bbd", "Barbado\u0161ki dolar" },
-            { "bdt", "Banglade\u0161ka taka" },
+            { "bam", "bosansko-hercegova\u010dka konvertibilna marka" },
+            { "bbd", "barbado\u0161ki dolar" },
+            { "bdt", "banglade\u0161ka taka" },
             { "bec", "Belgijski franak (konvertibilni)" },
             { "bef", "Belgijski franak" },
             { "bel", "Belgijski franak (finansijski)" },
             { "bgl", "Bugarski tvrdi lev" },
-            { "bgn", "Bugarski lev" },
-            { "bhd", "Bahreinski dinar" },
-            { "bif", "Burundski franak" },
-            { "bmd", "Bermudski dolar" },
-            { "bnd", "Brunejski dolar" },
-            { "bob", "Bolivijski bolivijano" },
+            { "bgn", "bugarski lev" },
+            { "bhd", "bahreinski dinar" },
+            { "bif", "burundski franak" },
+            { "bmd", "bermudski dolar" },
+            { "bnd", "brunejski dolar" },
+            { "bob", "bolivijski bolivijano" },
             { "bop", "Bolivijski pezo" },
             { "bov", "Bolivijski mvdol" },
             { "brb", "Brazilski novi kruzeiro (1967\u20131986)" },
             { "brc", "Brazilijski kruzado" },
             { "bre", "Brazilski kruzeiro (1990\u20131993)" },
-            { "brl", "Brazilski real" },
+            { "brl", "brazilski real" },
             { "brn", "Brazilijski novi kruzado" },
             { "brr", "Brazilski kruzeiro" },
-            { "bsd", "Bahamski dolar" },
-            { "btn", "Butanski ngultrum" },
+            { "bsd", "bahamski dolar" },
+            { "btn", "butanski ngultrum" },
             { "buk", "Burmanski kjat" },
-            { "bwp", "Bocvanska pula" },
+            { "bwp", "bocvanska pula" },
             { "byb", "Beloruska nova rublja (1994\u20131999)" },
-            { "byn", "Beloruska rublja" },
+            { "byn", "beloruska rublja" },
             { "byr", "Beloruska rublja (2000\u20132016)" },
-            { "bzd", "Beliski dolar" },
-            { "cad", "Kanadski dolar" },
-            { "cdf", "Kongoanski franak" },
+            { "bzd", "beliski dolar" },
+            { "cad", "kanadski dolar" },
+            { "cdf", "kongoanski franak" },
             { "che", "WIR evro" },
-            { "chf", "\u0160vajcarski franak" },
+            { "chf", "\u0161vajcarski franak" },
             { "chw", "WIR franak" },
             { "clf", "\u010cileovski unidades se fomento" },
-            { "clp", "\u010cileanski pezos" },
-            { "cnh", "Kineski juan (ostrvski)" },
-            { "cny", "Kineski juan" },
-            { "cop", "Kolumbijski pezos" },
+            { "clp", "\u010dileanski pezos" },
+            { "cnh", "kineski juan (ostrvski)" },
+            { "cny", "kineski juan" },
+            { "cop", "kolumbijski pezos" },
             { "cou", "Unidad de valor\u0161ki real" },
-            { "crc", "Kostarikanski kolon" },
+            { "crc", "kostarikanski kolon" },
             { "csd", "Stari srpski dinar" },
             { "csk", "\u010cehoslova\u010dka tvrda kruna" },
-            { "cuc", "Kubanski konvertibilni pezos" },
-            { "cup", "Kubanski pezos" },
-            { "cve", "Zelenortski eskudo" },
+            { "cuc", "kubanski konvertibilni pezos" },
+            { "cup", "kubanski pezos" },
+            { "cve", "zelenortski eskudo" },
             { "cyp", "Kiparska funta" },
-            { "czk", "\u010ce\u0161ka kruna" },
+            { "czk", "\u010de\u0161ka kruna" },
             { "ddm", "Isto\u010dno-nema\u010dka marka" },
             { "dem", "Nema\u010dka marka" },
-            { "djf", "D\u017eibutanski franak" },
-            { "dkk", "Danska kruna" },
-            { "dop", "Dominikanski pezos" },
-            { "dzd", "Al\u017eirski dinar" },
+            { "djf", "d\u017eibutski franak" },
+            { "dkk", "danska kruna" },
+            { "dop", "dominikanski pezos" },
+            { "dzd", "al\u017eirski dinar" },
             { "ecs", "Ekvadorski sakr" },
             { "ecv", "Ekvadorski unidad de valor konstante" },
             { "eek", "Estonska kroon" },
-            { "egp", "Egipatska funta" },
-            { "ern", "Eritrejska nakfa" },
+            { "egp", "egipatska funta" },
+            { "ern", "eritrejska nakfa" },
             { "esa", "\u0160panska pezeta (ra\u010dun)" },
             { "esb", "\u0160panska pezeta (konvertibilnira\u010dun)" },
             { "esp", "\u0160panska pezeta" },
-            { "etb", "Etiopski bir" },
+            { "etb", "etiopijski bir" },
             { "eur", "Evro" },
             { "fim", "Finska marka" },
-            { "fjd", "Fid\u017eijski dolar" },
-            { "fkp", "Foklandska funta" },
+            { "fjd", "fid\u017eijski dolar" },
+            { "fkp", "folklandska funta" },
             { "frf", "Francuski franak" },
-            { "gbp", "Britanska funta" },
+            { "gbp", "britanska funta" },
             { "gek", "Gruzijski kupon larit" },
-            { "gel", "Gruzijski lari" },
+            { "gel", "gruzijski lari" },
             { "ghc", "Ganski cedi (1979\u20132007)" },
-            { "ghs", "Ganski sedi" },
-            { "gip", "Gibraltarska funta" },
-            { "gmd", "Gambijski dalasi" },
-            { "gnf", "Gvinejski franak" },
+            { "ghs", "ganski sedi" },
+            { "gip", "gibraltarska funta" },
+            { "gmd", "gambijski dalasi" },
+            { "gnf", "gvinejski franak" },
             { "gns", "Gvinejski sili" },
             { "gqe", "Ekvatorijalno-gvinejski ekvele" },
             { "grd", "Gr\u010dka drahma" },
-            { "gtq", "Gvatemalski kecal" },
+            { "gtq", "gvatemalski kecal" },
             { "gwe", "Portugalska gvineja eskudo" },
             { "gwp", "Gvineja Bisao Pezo" },
-            { "gyd", "Gvajanski dolar" },
-            { "hkd", "Hongkon\u0161ki dolar" },
-            { "hnl", "Hondura\u0161ka lempira" },
+            { "gyd", "gvajanski dolar" },
+            { "hkd", "hongkon\u0161ki dolar" },
+            { "hnl", "hondura\u0161ka lempira" },
             { "hrd", "Hrvatski dinar" },
-            { "hrk", "Hrvatska kuna" },
-            { "htg", "Hai\u0107anski gurd" },
-            { "huf", "Ma\u0111arska forinta" },
-            { "idr", "Indone\u017eanska rupija" },
+            { "hrk", "hrvatska kuna" },
+            { "htg", "hai\u0107anski gurd" },
+            { "huf", "ma\u0111arska forinta" },
+            { "idr", "indone\u017eanska rupija" },
             { "iep", "Irska funta" },
             { "ilp", "Izraelska funta" },
             { "ilr", "Stari izraelski \u0161ekeli" },
-            { "ils", "Izraelski novi \u0161ekel" },
-            { "inr", "Indijska rupija" },
-            { "iqd", "Ira\u010dki dinar" },
-            { "irr", "Iranski rijal" },
+            { "ils", "izraelski novi \u0161ekel" },
+            { "inr", "indijska rupija" },
+            { "iqd", "ira\u010dki dinar" },
+            { "irr", "iranski rijal" },
             { "isj", "Stara islandska kruna" },
-            { "isk", "Islandska kruna" },
+            { "isk", "islandska kruna" },
             { "itl", "Italijanska lira" },
-            { "jmd", "Jamaj\u010danski dolar" },
-            { "jod", "Jordanski dinar" },
-            { "jpy", "Japanski jen" },
-            { "kes", "Kenijski \u0161iling" },
-            { "kgs", "Kirgistanski som" },
-            { "khr", "Kambod\u017eanski rijel" },
-            { "kmf", "Komorski franak" },
-            { "kpw", "Severnokorejski von" },
-            { "krw", "Ju\u017enokorejski von" },
-            { "kwd", "Kuvajtski dinar" },
-            { "kyd", "Kajmanski dolar" },
-            { "kzt", "Kazahstanski tenge" },
-            { "lak", "Lao\u0161ki kip" },
-            { "lbp", "Libanska funta" },
-            { "lkr", "\u0160rilankanska rupija" },
-            { "lrd", "Liberijski dolar" },
-            { "lsl", "Lesoto loti" },
+            { "jmd", "jamaj\u010danski dolar" },
+            { "jod", "jordanski dinar" },
+            { "jpy", "japanski jen" },
+            { "kes", "kenijski \u0161iling" },
+            { "kgs", "kirgistanski som" },
+            { "khr", "kambod\u017eanski rijel" },
+            { "kmf", "komorski franak" },
+            { "kpw", "severnokorejski von" },
+            { "krw", "ju\u017enokorejski von" },
+            { "kwd", "kuvajtski dinar" },
+            { "kyd", "kajmanski dolar" },
+            { "kzt", "kazahstanski tenge" },
+            { "lak", "laoski kip" },
+            { "lbp", "libanska funta" },
+            { "lkr", "\u0161rilan\u010danska rupija" },
+            { "lrd", "liberijski dolar" },
+            { "lsl", "lesotski loti" },
             { "ltl", "Litvanski litas" },
             { "ltt", "Litvanski talonas" },
             { "luc", "Luksembur\u0161ki konvertibilni franak" },
@@ -233,125 +218,126 @@ public class CurrencyNames_sr_Latn extends OpenListResourceBundle {
             { "lul", "Luksembur\u0161ki finansijski franak" },
             { "lvl", "Latvijski lati" },
             { "lvr", "Latvijska rublja" },
-            { "lyd", "Libijski dinar" },
-            { "mad", "Marokanski dirham" },
+            { "lyd", "libijski dinar" },
+            { "mad", "marokanski dirham" },
             { "maf", "Marokanski franak" },
-            { "mdl", "Moldavski lej" },
-            { "mga", "Madagaskarski ariari" },
+            { "mdl", "moldavski lej" },
+            { "mga", "malga\u0161ki arijari" },
             { "mgf", "Malagasijski franak" },
-            { "mkd", "Makedonski denar" },
+            { "mkd", "makedonski denar" },
             { "mlf", "Malijanski franak" },
-            { "mmk", "Mjanmarski kjat" },
-            { "mnt", "Mongolski tugrik" },
-            { "mop", "Makaoska pataka" },
+            { "mmk", "mjanmarski kjat" },
+            { "mnt", "mongolski tugrik" },
+            { "mop", "makaoska pataka" },
             { "mro", "Mauritanijska ogija (1973\u20132017)" },
-            { "mru", "Mauritanijska ogija" },
+            { "mru", "mauritanska ogija" },
             { "mtl", "Malte\u0161ka lira" },
             { "mtp", "Malte\u0161ka funta" },
-            { "mur", "Mauricijska rupija" },
-            { "mvr", "Maldivska rufija" },
-            { "mwk", "Malavijska kva\u010da" },
-            { "mxn", "Meksi\u010dki pezos" },
+            { "mur", "mauricijska rupija" },
+            { "mvr", "maldivska rufija" },
+            { "mwk", "malavijska kva\u010da" },
+            { "mxn", "meksi\u010dki pezos" },
             { "mxp", "Meksi\u010dki srebrni pezo (1861\u20131992)" },
             { "mxv", "Meksi\u010dki unidad de inversion (UDI)" },
-            { "myr", "Malezijski ringit" },
+            { "myr", "malezijski ringit" },
             { "mze", "Mozambijski eskudo" },
             { "mzm", "Stari mozambijski metikal" },
-            { "mzn", "Mozambi\u010dki metikal" },
-            { "nad", "Namibijski dolar" },
-            { "ngn", "Nigerijska naira" },
-            { "nic", "Nikaragvanska kordoba" },
-            { "nio", "Nikaragvanska zlatna kordoba" },
+            { "mzn", "mozambi\u010dki metikal" },
+            { "nad", "namibijski dolar" },
+            { "ngn", "nigerijska naira" },
+            { "nic", "nikaragvanska kordoba (1988\u20131991)" },
+            { "nio", "nikaragvanska kordoba" },
             { "nlg", "Holandski gulden" },
-            { "nok", "Norve\u0161ka kruna" },
-            { "npr", "Nepalska rupija" },
-            { "nzd", "Novozelandski dolar" },
-            { "omr", "Omanski rijal" },
-            { "pab", "Panamska balboa" },
+            { "nok", "norve\u0161ka kruna" },
+            { "npr", "nepalska rupija" },
+            { "nzd", "novozelandski dolar" },
+            { "omr", "omanski rijal" },
+            { "pab", "panamska balboa" },
             { "pei", "Peruanski inti" },
-            { "pen", "Peruanski sol" },
+            { "pen", "peruanski sol" },
             { "pes", "Peruanski sol (1863\u20131965)" },
-            { "pgk", "Papuanska kina" },
-            { "php", "Filipinski pezos" },
-            { "pkr", "Pakistanska rupija" },
-            { "pln", "Poljski zlot" },
+            { "pgk", "papuanska kina" },
+            { "php", "filipinski pezos" },
+            { "pkr", "pakistanska rupija" },
+            { "pln", "poljski zlot" },
             { "plz", "Poljski zloti (1950\u20131995)" },
             { "pte", "Portugalski eskudo" },
-            { "pyg", "Paragvajski gvarani" },
-            { "qar", "Katarski rijal" },
+            { "pyg", "paragvajski gvarani" },
+            { "qar", "katarski rijal" },
             { "rhd", "Rodejskidolar" },
             { "rol", "Rumunski lej (1952\u20132006)" },
-            { "ron", "Rumunski lej" },
-            { "rsd", "Srpski dinar" },
-            { "rub", "Ruska rublja" },
+            { "ron", "rumunski lej" },
+            { "rsd", "srpski dinar" },
+            { "rub", "ruska rublja" },
             { "rur", "Ruska rublja (1991\u20131998)" },
-            { "rwf", "Ruandski franak" },
-            { "sar", "Saudijski rijal" },
-            { "sbd", "Solomonski dolar" },
-            { "scr", "Sej\u0161elska rupija" },
+            { "rwf", "ruandski franak" },
+            { "sar", "saudijski rijal" },
+            { "sbd", "solomonski dolar" },
+            { "scr", "sej\u0161elska rupija" },
             { "sdd", "Stari sudanski dinar" },
-            { "sdg", "Sudanska funta" },
+            { "sdg", "sudanska funta" },
             { "sdp", "Stara sudanska funta" },
-            { "sek", "\u0160vedska kruna" },
-            { "sgd", "Singapurski dolar" },
-            { "shp", "Sv. jelenska funta" },
+            { "sek", "\u0161vedska kruna" },
+            { "sgd", "singapurski dolar" },
+            { "shp", "funta Svete Jelene" },
             { "sit", "Slovena\u010dki tolar" },
             { "skk", "Slova\u010dka kruna" },
-            { "sll", "Sijeraleonski leone" },
-            { "sos", "Somalijski \u0161iling" },
-            { "srd", "Surinamski dolar" },
+            { "sle", "sijeraleonski leone" },
+            { "sll", "sijeraleonski leone (1964\u20142022)" },
+            { "sos", "somalijski \u0161iling" },
+            { "srd", "surinamski dolar" },
             { "srg", "Surinamski gilder" },
-            { "ssp", "Ju\u017enosudanska funta" },
+            { "ssp", "ju\u017enosudanska funta" },
             { "std", "Saotomska dobra (1977\u20132017)" },
-            { "stn", "Saotomska dobra" },
+            { "stn", "saotomska dobra" },
             { "sur", "Sovjetska rublja" },
             { "svc", "Salvadorski kolon" },
-            { "syp", "Sirijska funta" },
-            { "szl", "Svazilendski lilangeni" },
-            { "thb", "Tajlandski bat" },
+            { "syp", "sirijska funta" },
+            { "szl", "svazilendski lilangeni" },
+            { "thb", "tajlandski bat" },
             { "tjr", "Tad\u017eihistanska rublja" },
-            { "tjs", "Tad\u017eikistanski somon" },
+            { "tjs", "tad\u017eikistanski somon" },
             { "tmm", "Turkmenistanski manat (1993\u20132009)" },
-            { "tmt", "Turkmenistanski manat" },
-            { "tnd", "Tuniski dinar" },
-            { "top", "Tonganska panga" },
+            { "tmt", "turkmenistanski manat" },
+            { "tnd", "tuniski dinar" },
+            { "top", "tonganska panga" },
             { "tpe", "Timor\u0161ki eskudo" },
             { "trl", "Turska lira (1922\u20132005)" },
-            { "try", "Turska lira" },
+            { "try", "turska lira" },
             { "ttd", "Trinidad-tobago\u0161ki dolar" },
-            { "twd", "Novi tajvanski dolar" },
-            { "tzs", "Tanzanijski \u0161iling" },
-            { "uah", "Ukrajinska hrivnja" },
+            { "twd", "novi tajvanski dolar" },
+            { "tzs", "tanzanijski \u0161iling" },
+            { "uah", "ukrajinska grivna" },
             { "uak", "Ukrajinski karbovaneti" },
             { "ugs", "Ugandski \u0161iling (1966\u20131987)" },
-            { "ugx", "Ugandski \u0161iling" },
-            { "usd", "Ameri\u010dki dolar" },
+            { "ugx", "ugandski \u0161iling" },
+            { "usd", "ameri\u010dki dolar" },
             { "usn", "SAD dolar (slede\u0107i dan)" },
             { "uss", "SAD dolar (isti dan)" },
             { "uyi", "Urugvajski pezo en unidades indeksadas" },
             { "uyp", "Urugvajski pezo (1975\u20131993)" },
-            { "uyu", "Urugvajski pezos" },
-            { "uzs", "Uzbekistanski som" },
+            { "uyu", "urugvajski pezos" },
+            { "uzs", "uzbekistanski som" },
             { "veb", "Venecuelanski bolivar (1871\u20132008)" },
             { "vef", "Venecuelanski bolivar (2008\u20132018)" },
-            { "ves", "Venecuelanski bolivar" },
-            { "vnd", "Vijetnamski dong" },
+            { "ves", "venecuelanski bolivar" },
+            { "vnd", "vijetnamski dong" },
             { "vnn", "Vijetnamski dong (1978\u20131985)" },
-            { "vuv", "Vanuatski vatu" },
-            { "wst", "Samoanska tala" },
-            { "xaf", "CFA franak BEAC" },
+            { "vuv", "vanuatski vatu" },
+            { "wst", "samoanska tala" },
+            { "xaf", "centralnoafri\u010dki franak" },
             { "xag", "Srebro" },
             { "xau", "Zlato" },
             { "xba", "Evropska kompozitna jedinica" },
             { "xbb", "Evropska nov\u010dana jedinica" },
             { "xbc", "Evropska jedinica ra\u010duna (XBC)" },
             { "xbd", "Evropska jedinica ra\u010duna (XBD)" },
-            { "xcd", "Isto\u010dnokaripski dolar" },
+            { "xcd", "isto\u010dnokaripski dolar" },
             { "xdr", "Posebna crta\u0107a prava" },
             { "xeu", "Evropska valutna jedinica" },
             { "xfo", "Francuski zlatni franak" },
             { "xfu", "Francuski UIC-franak" },
-            { "xof", "CFA franak BCEAO" },
+            { "xof", "zapadnoafri\u010dki franak" },
             { "xpd", "Paladijum" },
             { "xpf", "CFP franak" },
             { "xpt", "Platina" },
@@ -359,14 +345,14 @@ public class CurrencyNames_sr_Latn extends OpenListResourceBundle {
             { "xts", "Kod testirane valute" },
             { "xxx", "Nepoznata valuta" },
             { "ydd", "Jemenski dinar" },
-            { "yer", "Jemenski rijal" },
+            { "yer", "jemenski rijal" },
             { "yud", "Jugoslovenski tvrdi dinar" },
             { "yum", "Jugoslovenski novi dinar" },
             { "yun", "Jugoslovenski konvertibilni dinar" },
             { "zal", "Ju\u017eno-afri\u010dki rand (finansijski)" },
-            { "zar", "Ju\u017enoafri\u010dki rand" },
+            { "zar", "ju\u017enoafri\u010dki rand" },
             { "zmk", "Zambijska kva\u010da (1968\u20132012)" },
-            { "zmw", "Zambijska kva\u010da" },
+            { "zmw", "zambijska kva\u010da" },
             { "zrn", "Zairski novi zair" },
             { "zrz", "Zairski zair" },
             { "zwd", "Zimbabveanski dolar (1980\u20132008)" },
