@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -91,6 +91,7 @@ public class LocaleNames_da extends OpenListResourceBundle {
         final String metaValue_ml = "malayalam";
         final String metaValue_mn = "mongolsk";
         final String metaValue_my = "burmesisk";
+        final String metaValue_nqo = "n\u2019ko";
         final String metaValue_or = "oriya";
         final String metaValue_pal = "pahlavi";
         final String metaValue_phn = "f\u00f8nikisk";
@@ -404,7 +405,7 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "af", "afrikaans" },
             { "ak", "akan" },
             { "am", "amharisk" },
-            { "an", "aragonesisk" },
+            { "an", "aragonsk" },
             { "ar", metaValue_ar },
             { "as", "assamesisk" },
             { "av", "avarisk" },
@@ -426,7 +427,7 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "cr", "cree" },
             { "cs", "tjekkisk" },
             { "cu", "kirkeslavisk" },
-            { "cv", "chuvash" },
+            { "cv", "tjuvasjisk" },
             { "cy", "walisisk" },
             { "da", "dansk" },
             { "de", "tysk" },
@@ -613,6 +614,7 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "bem", "bemba" },
             { "bez", "bena" },
             { "bfd", "bafut" },
+            { "bgc", "harianvi" },
             { "bgn", "vestbaluchi" },
             { "bho", "bhojpuri" },
             { "bik", "bikol" },
@@ -727,7 +729,7 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "jpr", "j\u00f8disk-persisk" },
             { "jrb", "j\u00f8disk-arabisk" },
             { "kaa", "karakalpakisk" },
-            { "kab", "kabylisk" },
+            { "kab", "kabylsk" },
             { "kac", "kachin" },
             { "kaj", "jju" },
             { "kam", "kamba" },
@@ -818,7 +820,7 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "nnh", "ngiemboon" },
             { "nog", "nogai" },
             { "non", "oldislandsk" },
-            { "nqo", "n-ko" },
+            { "nqo", metaValue_nqo },
             { "nso", "nordsotho" },
             { "nus", "nuer" },
             { "nwc", "klassisk newarisk" },
@@ -889,7 +891,7 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "suk", "sukuma" },
             { "sus", "susu" },
             { "sux", "sumerisk" },
-            { "swb", "shimaore" },
+            { "swb", "comorisk" },
             { "syc", "klassisk syrisk" },
             { "syr", metaValue_syr },
             { "tce", "sydtutchone" },
@@ -1042,7 +1044,7 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "Narb", "gammelt nordarabisk" },
             { "Nbat", "nabateisk" },
             { "Nkgb", "nakhi geba" },
-            { "Nkoo", "n\u2019ko" },
+            { "Nkoo", metaValue_nqo },
             { "Nshu", "n\u00fcshu" },
             { "Ogam", "ogham" },
             { "Olck", "ol-chiki" },
@@ -1270,7 +1272,7 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "type.ms.metric", "metersystem" },
             { "type.nu.native", "nationale tal" },
             { "type.ca.chinese", "kinesisk kalender" },
-            { "type.ca.islamic", "islamisk kalender" },
+            { "type.ca.islamic", "hijri-kalender" },
             { "type.ca.iso8601", "ISO-8601-kalender" },
             { "type.ca.persian", "persisk kalender" },
             { "type.cf.account", "format for regnskabsvaluta" },
@@ -1305,10 +1307,8 @@ public class LocaleNames_da extends OpenListResourceBundle {
             { "type.co.dictionary", "sorteringsr\u00e6kkef\u00f8lge for ordbog" },
             { "type.co.traditional", "traditionel sorteringsr\u00e6kkef\u00f8lge" },
             { "type.nu.traditional", "Traditionelle tal" },
-            { "type.ca.islamic-rgsa", "islamisk kalender (Saudi-Arabien, observation)" },
-            { "type.ca.islamic-tbla", "islamisk kalender (tabellarisk, astronomisk epoke)" },
-            { "type.ca.islamic-civil", "verdslig islamisk kalender" },
-            { "type.ca.islamic-umalqura", "islamisk kalender (Umm al-Qura)" },
+            { "type.ca.islamic-civil", "verdslig hijri-kalender" },
+            { "type.ca.islamic-umalqura", "hijri-kalender (Umm al-Qura)" },
             { "type.ca.ethiopic-amete-alem", "etiopisk amete-alem-kalender" },
         };
         return data;
