@@ -68,11 +68,11 @@ public class TimeZoneNames_bgc extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "\u0917\u094d\u0930\u0940\u0928\u0935\u093f\u091a \u092e\u0940\u0928 \u091f\u093e\u0907\u092e",
+               "GMT",
                "",
+               "BST",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] EMPTY_ZONE = new String[] {
                "",
