@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -92,11 +92,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "heure normale de Cuba",
-               "",
+               "CST",
                "heure avanc\u00e9e de Cuba",
-               "",
+               "CDT",
                "heure de Cuba",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "heure normale des \u00eeles Fidji",
@@ -156,35 +156,35 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "heure normale de Chine",
-               "",
+               "CST",
                "heure avanc\u00e9e de Chine",
-               "",
+               "CDT",
                "heure de Chine",
-               "",
+               "CT",
             };
         final String[] Japan = new String[] {
                "heure normale du Japon",
-               "",
+               "JST",
                "heure avanc\u00e9e du Japon",
-               "",
+               "JDT",
                "heure du Japon",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "heure normale de la Cor\u00e9e",
-               "",
+               "KST",
                "heure avanc\u00e9e de Cor\u00e9e",
-               "",
+               "KST",
                "heure de la Cor\u00e9e",
-               "",
+               "KST",
             };
         final String[] Samoa = new String[] {
                "heure normale des Samoa",
-               "",
+               "SST",
                "heure avanc\u00e9e des Samoa",
-               "",
+               "SST",
                "heure des Samoa",
-               "",
+               "SST",
             };
         final String[] Tonga = new String[] {
                "heure normale des Tonga",
@@ -196,11 +196,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "heure normale de l\u2019Alaska",
-               "",
+               "AKST",
                "heure avanc\u00e9e de l\u2019Alaska",
-               "",
+               "AKDT",
                "heure de l\u2019Alaska",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "heure normale de l\u2019Amazonie",
@@ -244,27 +244,27 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "heure normale d\u2019Isra\u00ebl",
-               "",
+               "IST",
                "heure avanc\u00e9e d\u2019Isra\u00ebl",
-               "",
+               "IDT",
                "heure d\u2019Isra\u00ebl",
-               "",
+               "IT",
             };
         final String[] Moscow = new String[] {
                "heure normale de Moscou",
-               "",
+               "MSK",
                "heure avanc\u00e9e de Moscou",
-               "",
+               "MSK",
                "heure de Moscou",
-               "",
+               "MSK",
             };
         final String[] Taipei = new String[] {
                "heure normale de Taipei",
-               "",
+               "CST",
                "heure avanc\u00e9e de Taipei",
-               "",
+               "CDT",
                "heure de Taipei",
-               "",
+               "CT",
             };
         final String[] Arabian = new String[] {
                "heure normale de l\u2019Arabie",
@@ -356,11 +356,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "heure normale de l\u2019Atlantique",
-               "",
+               "AST",
                "heure avanc\u00e9e de l\u2019Atlantique",
-               "",
+               "ADT",
                "heure de l\u2019Atlantique",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "heure normale de Brasilia",
@@ -396,11 +396,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "heure normale du Pakistan",
-               "",
+               "PKT",
                "heure avanc\u00e9e du Pakistan",
-               "",
+               "PKST",
                "heure du Pakistan",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "heure normale du Paraguay",
@@ -428,11 +428,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "heure normale de Hong Kong",
-               "",
+               "HKT",
                "heure avanc\u00e9e de Hong Kong",
-               "",
+               "HKST",
                "heure de Hong Kong",
-               "",
+               "HKT",
             };
         final String[] Kamchatka = new String[] {
                "heure normale de Petropavlovsk-Kamchatski",
@@ -460,11 +460,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "heure normale de Volgograd",
-               "",
+               "MSK",
                "heure avanc\u00e9e de Volgograd",
-               "",
+               "MSK",
                "heure de Volgograd",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "heure normale de l\u2019Azerba\u00efdjan",
@@ -516,11 +516,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "heure normale de la Nouvelle-Z\u00e9lande",
-               "",
+               "NZST",
                "heure avanc\u00e9e de la Nouvelle-Z\u00e9lande",
-               "",
+               "NZDT",
                "heure de la Nouvelle-Z\u00e9lande",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "heure normale de Novossibirsk",
@@ -532,11 +532,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "heure normale des Philippines",
-               "",
+               "PST",
                "heure avanc\u00e9e des Philippines",
-               "",
+               "PDT",
                "heure des Philippines",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "heure normale de Vladivostok",
@@ -588,67 +588,67 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "heure d\u2019Afrique centrale",
+               "CAT",
                "",
+               "CAT",
                "",
-               "",
-               "",
-               "",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "heure d\u2019Afrique orientale",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "heure normale d\u2019Afrique de l\u2019Ouest",
-               "",
+               "WAT",
                "heure avanc\u00e9e d\u2019Afrique de l\u2019Ouest",
-               "",
+               "WAT",
                "heure d\u2019Afrique de l\u2019Ouest",
-               "",
+               "WAT",
             };
         final String[] Europe_Central = new String[] {
                "heure normale de l\u2019Europe centrale",
-               "",
+               "CET",
                "heure avanc\u00e9e de l\u2019Europe centrale",
-               "",
+               "CEST",
                "heure de l\u2019Europe centrale",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "heure normale de l\u2019Europe de l\u2019Est",
-               "",
+               "EET",
                "heure avanc\u00e9e de l\u2019Europe de l\u2019Est",
-               "",
+               "EEST",
                "heure de l\u2019Europe de l\u2019Est",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "heure normale de l\u2019Europe de l\u2019Ouest",
-               "",
+               "WET",
                "heure avanc\u00e9e de l\u2019Europe de l\u2019Ouest",
-               "",
+               "WEST",
                "heure de l\u2019Europe de l\u2019Ouest",
-               "",
+               "WET",
             };
         final String[] Mexico_Pacific = new String[] {
                "heure normale du Pacifique mexicain",
-               "",
+               "MST",
                "heure avanc\u00e9e du Pacifique mexicain",
-               "",
+               "MDT",
                "heure du Pacifique mexicain",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "heure normale d\u2019Afrique du Sud",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "heure normale du Centre",
@@ -676,11 +676,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "heure normale d\u2019Hawa\u00ef-Al\u00e9outiennes",
-               "",
+               "HST",
                "heure avanc\u00e9e d\u2019Hawa\u00ef-Al\u00e9outiennes",
-               "",
+               "HST",
                "heure d\u2019Hawa\u00ef-Al\u00e9outiennes",
-               "",
+               "HST",
             };
         final String[] Pierre_Miquelon = new String[] {
                "heure normale de Saint-Pierre-et-Miquelon",
@@ -708,27 +708,27 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "heure normale du centre de l\u2019Australie",
-               "",
+               "ACST",
                "heure avanc\u00e9e du centre de l\u2019Australie",
-               "",
+               "ACDT",
                "heure du centre de l\u2019Australie",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "heure normale de l\u2019Est de l\u2019Australie",
-               "",
+               "AEST",
                "heure avanc\u00e9e de l\u2019Est de l\u2019Australie",
-               "",
+               "AEDT",
                "heure de l\u2019Est de l\u2019Australie",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "heure normale de l\u2019Ouest de l\u2019Australie",
-               "",
+               "AWST",
                "heure avanc\u00e9e de l\u2019Ouest de l\u2019Australie",
-               "",
+               "AWDT",
                "heure de l\u2019Ouest de l\u2019Australie",
-               "",
+               "AWT",
             };
         final String[] Greenland_Eastern = new String[] {
                "heure normale de l\u2019Est du Groenland",
@@ -875,22 +875,22 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "",
-                    "",
+                    "GMT",
                     "heure avanc\u00e9e irlandaise",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
                     "",
-                    "",
+                    "GMT",
                     "heure avanc\u00e9e britannique",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -935,11 +935,11 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "",
-                    "",
+                    "GMT",
                     "heure avanc\u00e9e britannique",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
